@@ -63,6 +63,15 @@ export const registerBbyButtons = () => {
       'add-verify-step',
       'ipybbycell'
     ),
+    Jupyter.keyboard_manager.actions.register(
+      {
+        help: '添加「OJ Step」',
+        icon: 'fa-magic',
+        handler: addOjStep,
+      },
+      'add-oj-step',
+      'ipybbycell'
+    ),
     Jupyter.keyboard_manager.actions.register(
       {
         help: '添加「Matplotlib Step」',
@@ -227,6 +236,56 @@ print("add(0) =", x)`);
   insertMarkdownCellBelow('add(0) = 1');
 };
 
+const addOjStep = function () {
+  insertMarkdownCellBelow('### 步骤标题');
+
+  insertCodeCellBelow(`#platform-desc
+`);
+
+  insertMarkdownCellBelow(`#### 题目描述
+
+在此处填写题目描述
+
+#### 输入描述
+
+在此处填写输入描述
+
+#### 输出描述
+
+在此处填写输出描述
+
+#### 输入样例
+
+在此处填写输入样例
+
+#### 输出样例
+
+在此处填写输出样例
+`);
+
+  insertCodeCellBelow(`//platform-edit
+#include <iostream>
+using namespace std;
+
+int main(){
+    
+    return 0;
+}`);
+
+  insertCodeCellBelow(`//platform-edit-answer
+//参考答案
+#include <iostream>
+using namespace std;
+
+int main(){
+
+    
+    return 0;
+}`);
+
+  insertMarkdownCellBelow(`ONLINE_JUDGE_PROBLEM_ID=XXX`);
+}
+
 const addLesson = function () {
   Jupyter.notebook.insert_cell_below('markdown').set_text(`## 单元标题
 
